@@ -1,9 +1,12 @@
 # coding: utf-8
 import re
-from .word_cleanup import word_cleanup
-from ..utils.profile_entries import profile_entries
 
-# from ..utils.bo_sorted import bo_sorted
+from tibetan_sort import TibetanSort
+
+from ..utils.profile_entries import profile_entries
+from .word_cleanup import word_cleanup
+
+sort = TibetanSort()
 
 
 def parse_corrected(in_str):
@@ -40,9 +43,8 @@ def extract_new_entries(in_str, profile_path):
             entry_data.append(e_d)
 
     # sort both lists
-    # words = bo_sorted(words)
-    # entry_data = bo_sorted(entry_data)
-    entry_data = sorted(entry_data)
+    # words = sort.sort_list(words)
+    entry_data = sort.sort_list(entry_data)
     entry_data = ["# form	pos	lemma	sense	freq"] + entry_data
 
     return "\n".join(entry_data)
